You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by fu...@apache.org on 2007/03/08 23:15:37 UTC

svn commit: r516194 [2/2] - in /db/derby/code/trunk/java/engine/org/apache/derby/iapi: db/ error/ jdbc/ reference/ services/cache/ services/compiler/ services/context/ services/crypto/ services/daemon/ services/diag/ services/i18n/ services/info/ servi...

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/RawStoreFactory.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/RawStoreFactory.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/StreamContainerHandle.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/StreamContainerHandle.java Thu Mar  8 14:15:34 2007
@@ -85,7 +85,7 @@
 
 		@param row Row to be filled in with information from the record.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	*/
 	boolean fetchNext(DataValueDescriptor[] row) throws StandardException;
 
@@ -105,7 +105,7 @@
 	/**
 		remove the stream container
 
-		@exception StandardException Standard Cloudscape error policy		
+		@exception StandardException Standard Derby error policy		
 	 */
 	public void removeContainer() throws StandardException;
 }

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/Transaction.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/Transaction.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/Transaction.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/Transaction.java Thu Mar  8 14:15:34 2007
@@ -66,7 +66,7 @@
 
 		Will not be called for transactions early in the boot process, ie. before
 		the property conglomerate is set up.
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public void setup(PersistentSet set)
 		throws StandardException;
@@ -200,7 +200,7 @@
 
 		@see RawStoreFactory#startTransaction
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception StandardException A transaction level exception is 
         thrown if the transaction is not idle.
 
@@ -213,7 +213,7 @@
 
 		@see RawStoreFactory#startTransaction
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception StandardException A transaction level exception is 
         thrown if the transaction is not idle.
 
@@ -236,7 +236,7 @@
                     A JDBC Savepoint object value for kindOfSavepoint would mean it is JDBC savepoint
 
 		@return returns total number of savepoints in the stack.
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 		@exception StandardException
         A statement level exception is thrown if a savepoint already 
         exists in the current transaction with the same name.
@@ -257,7 +257,7 @@
                     A JDBC Savepoint object value for kindOfSavepoint would mean it is JDBC savepoint
 
 		@return returns total number of savepoints in the stack.
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 		@exception StandardException
         A statement level exception is thrown if a savepoint already
         exists in the current transaction with the same name.
@@ -280,7 +280,7 @@
                     A JDBC Savepoint object value for kindOfSavepoint would mean it is JDBC savepoint
 
 		@return returns total number of savepoints in the stack.
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 		@exception StandardException
         A statement level exception is thrown if no savepoint exists with 
         the given name.
@@ -304,7 +304,7 @@
 
 		@return a valid ContainerHandle or null if the container does not exist.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 
 	*/
 	public ContainerHandle openContainer(ContainerKey containerId,  int mode)
@@ -326,7 +326,7 @@
 
 		@return a valid ContainerHandle or null if the container does not exist.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 
 	*/
 
@@ -373,7 +373,7 @@
 		This id is only valid within this RawStoreFactory.  Returns a negative 
         number if a container could not be allocated.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 	*/
 	public long addContainer(
@@ -397,7 +397,7 @@
 		and all its pages deallocated. The container will be fully removed
 		at the commit time of the transaction.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 	*/
 	public void dropContainer(ContainerKey containerId)
@@ -420,7 +420,7 @@
 		and all its pages deallocated. The container will be fully removed
 		at the commit time of the transaction.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 	*/
 	public long addAndLoadStreamContainer(
@@ -433,7 +433,7 @@
 
 		@return a valid StreamContainerHandle or null if the container does not exist.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 
 	*/
 	public StreamContainerHandle openStreamContainer(
@@ -449,7 +449,7 @@
 		<P>
 		This call will remove the container.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 	*/
 	public abstract void dropStreamContainer(long segmentId, long containerId)
@@ -467,7 +467,7 @@
 
 		@see Loggable
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 
 	*/
 	public void logAndDo(Loggable operation) throws StandardException;

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/Undoable.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/Undoable.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/Undoable.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/Undoable.java Thu Mar  8 14:15:34 2007
@@ -95,7 +95,7 @@
 		null if nothing to undo. 
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 
 		@see Loggable#releaseResource
 		@see Loggable#needsRedo

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/data/DataFactory.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/data/DataFactory.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/log/LogFactory.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/log/LogFactory.java Thu Mar  8 14:15:34 2007
@@ -128,7 +128,7 @@
 
 		@return the LogScan.
 
-		@exception StandardException StandardCloudscape error policy
+		@exception StandardException Standard Derby error policy
 	    NOTE: This will be removed after the LogSniffer Rewrite.
 	*/
 	LogScan openForwardsFlushedScan(LogInstant startAt)
@@ -144,7 +144,7 @@
 		if startAt is a LogInstant which is not in the log.
 		@param groupsIWant - log record groups the scanner wants.
 		@return the LogScan.
-		@exception StandardException StandardCloudscape error policy
+		@exception StandardException Standard Derby error policy
 		*/
 	ScanHandle openFlushedScan(DatabaseInstant startAt, int groupsIWant)
 		 throws StandardException;
@@ -162,7 +162,7 @@
  		if stopAt is a LogInstant which is not in the log.
 		@return the LogScan.
 
-		@exception StandardException StandardCloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	LogScan openForwardsScan(LogInstant startAt,LogInstant stopAt)
 		 throws StandardException;
@@ -177,13 +177,13 @@
 
 	/**
 		Stop making any change to the persistent store
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 	 */
 	public void freezePersistentStore() throws StandardException;
 		 
 	/**
 		Can start making change to the persistent store again
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 	 */
 	public void unfreezePersistentStore() throws StandardException;
 
@@ -195,14 +195,14 @@
 
 	/**
 		Get JBMS properties relavent to the log factory
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public void getLogFactoryProperties(PersistentSet set) 
 		 throws StandardException;
 
 	 /**
 		Return the location of the log directory.
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	  */
 	public StorageFile getLogDirectory() throws StandardException;
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/log/Logger.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/log/Logger.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/log/Logger.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/log/Logger.java Thu Mar  8 14:15:34 2007
@@ -54,7 +54,7 @@
 		@param operation	the loggable operation that describes the change
 		@return LogInstant that is the LogInstant of the loggable operation 
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	   */ 
 	public LogInstant logAndDo(RawTransaction xact, Loggable operation)
 		 throws StandardException; 
@@ -79,7 +79,7 @@
 
 		@return LogInstant that is the LogInstant of the compensation operation
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	   */ 
 	public LogInstant logAndUndo(RawTransaction xact,
 								 Compensation operation, LogInstant undoInstant,
@@ -145,7 +145,7 @@
 				to be rolled back.  
 				If null, then rollback starts from the end of the log.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 	  */
 	public void undo(RawTransaction t,
 					 TransactionId undoId,

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/xact/RawTransaction.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/xact/RawTransaction.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/xact/RawTransaction.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/xact/RawTransaction.java Thu Mar  8 14:15:34 2007
@@ -120,7 +120,7 @@
 
 		@see Compensation
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public abstract void logAndUndo(Compensation compensation, LogInstant undoInstant, 
 									LimitObjectInput in) 
@@ -198,7 +198,7 @@
 		logical operations. Transactions that need to disallow logical 
         operations should hide this method.
 
-		@exception StandardException Standard Cloudscape error policy,
+		@exception StandardException Standard Derby error policy,
 	*/
 	public void checkLogicalOperationOk() throws StandardException {
 	}
@@ -249,7 +249,7 @@
 		A nested top transaction conflicts on the logical locks of its "parent"
         transaction.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 
 	public abstract RawTransaction startNestedTopTransaction() throws StandardException;
@@ -267,7 +267,7 @@
 		code always check for committed drop status.  Anybody else wanting to
 		use this interface must keep this in mind.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public abstract RawContainerHandle openDroppedContainer
 		(ContainerKey containerId, LockingPolicy locking)
@@ -279,7 +279,7 @@
         Used during redo recovery when processing log records trying to 
         create a container, but no container is found in the db.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	 */
 	public abstract void reCreateContainerForRedoRecovery
 		(long segmentId, long containerId, ByteArray containerInfo)

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/xact/TransactionFactory.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/xact/TransactionFactory.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/DataTypeDescriptor.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/DataTypeDescriptor.java Thu Mar  8 14:15:34 2007
@@ -912,7 +912,7 @@
 	 * SQL types. For example Types.NUMERIC and Types.DECIMAL are
 	 * equivalent
 	 *
-	 * @param existingType  JDBC type id of Cloudscape data type
+	 * @param existingType  JDBC type id of Derby data type
 	 * @param jdbcTypeId   JDBC type id passed in from application.
 	 *
 	 * @return boolean true if types are equivalent, false if not

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/JSQLType.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/JSQLType.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/JSQLType.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/JSQLType.java Thu Mar  8 14:15:34 2007
@@ -29,7 +29,7 @@
 import java.io.ObjectOutput;
 
 /**
- *	Type descriptor which wraps all 3 kinds of types supported in Cloudscape's
+ *	Type descriptor which wraps all 3 kinds of types supported in Derby's
  *	JSQL language: SQL types, Java primitives, Java classes.
  *
  *	This interface was originally added to support the serializing of WorkUnit

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLChar.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLChar.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLChar.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLChar.java Thu Mar  8 14:15:34 2007
@@ -633,7 +633,7 @@
     {
         arg_passer[0]        = rawData;
 
-        rawLength = in.readCloudscapeUTF(arg_passer);
+        rawLength = in.readDerbyUTF(arg_passer);
 
         rawData = arg_passer[0];
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/TypeId.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/TypeId.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/TypeId.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/TypeId.java Thu Mar  8 14:15:34 2007
@@ -110,7 +110,7 @@
         public static final int VARBIT_MAXWIDTH         = Limits.DB2_VARCHAR_MAXWIDTH;
         public static final int LONGVARBIT_MAXWIDTH = Limits.DB2_LONGVARCHAR_MAXWIDTH;
 
-        // not supposed to be limited! 4096G should be ok(?), if Cloudscape can handle...
+        // not supposed to be limited! 4096G should be ok(?), if Derby can handle...
         public static final int BLOB_MAXWIDTH = Integer.MAX_VALUE; // to change long
         public static final int CLOB_MAXWIDTH = Integer.MAX_VALUE; // to change long
         public static final int NCLOB_MAXWIDTH = Integer.MAX_VALUE; // to change long
@@ -610,7 +610,7 @@
 
                 TypeId ret = null;
 
-                // Types defined below here are SQL types and non-JDBC types that are supported by Cloudscape
+                // Types defined below here are SQL types and non-JDBC types that are supported by Derby
                 if (SQLTypeName.equals(TypeId.NCLOB_NAME)) {
                         ret = NCLOB_ID;
                         if (ret == null)
@@ -974,9 +974,9 @@
         }
         /**
          * JDBC has its own idea of type identifiers which is different from
-         * the Cloudscape internal type ids.  The JDBC type ids are defined
+         * the Derby internal type ids.  The JDBC type ids are defined
          * as public final static ints in java.sql.Types.  This method translates
-         * a Cloudscape internal TypeId to a JDBC type id. For java objects this
+         * a Derby internal TypeId to a JDBC type id. For java objects this
          * returns JAVA_OBJECT in Java2 and OTHER in JDK 1.1. For Boolean datatypes,
          * this returns Type.BOOLEAN in JDK1.4 and Type.BIT for jdks prior to 1.4
          *

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/util/StringUtil.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/util/StringUtil.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/util/StringUtil.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/util/StringUtil.java Thu Mar  8 14:15:34 2007
@@ -322,7 +322,7 @@
 	}
 
 	// The functions below are used for uppercasing SQL in a consistent manner.
-	// Cloudscape will uppercase Turkish to the English locale to avoid i
+	// Derby will uppercase Turkish to the English locale to avoid i
 	// uppercasing to an uppercase dotted i. In future versions, all 
 	// casing will be done in English.   The result will be that we will get
 	// only the 1:1 mappings  in
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/RawStoreFactory.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/RawStoreFactory.java Thu Mar  8 14:15:34 2007
@@ -410,7 +410,7 @@
         @param transName is the name of the transaction. Thsi name will be displayed
         by the transactiontable VTI.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 		@see Transaction
 		@see org.apache.derby.iapi.services.context.Context
@@ -471,7 +471,7 @@
         @param local_id   The branch qualifier of the Xid - ie. 
                           Xid.getBranchQaulifier()
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 		@see Transaction
 		@see org.apache.derby.iapi.services.context.Context
@@ -496,7 +496,7 @@
                           this name.
         The name is displayed in the transactiontable VTI.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 		@see #startTransaction
 	*/
@@ -549,7 +549,7 @@
         and the context is popped off the stack.
 		</UL>
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 		@see Transaction
 		@see org.apache.derby.iapi.services.context.Context
@@ -604,7 +604,7 @@
         @param transName is the name of the transaction. This name will be 
         displayed by the transactiontable VTI.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 		@see Transaction
 		@see org.apache.derby.iapi.services.context.Context
@@ -663,7 +663,7 @@
         @param transName is the name of the transaction. This name will be 
         displayed by the transactiontable VTI.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 		@see Transaction
 		@see org.apache.derby.iapi.services.context.Context
@@ -683,7 +683,7 @@
 
 	/**
 	  * Freeze the database temporarily so a backup can be taken.
 	  * <P>Please see cloudscape on line documentation on backup and restore.
 	  *
 	  * @exception StandardException Thrown on error
 	  */
@@ -691,7 +691,7 @@
 
 	/**
 	  * Unfreeze the database after a backup has been taken.
 	  * <P>Please see cloudscape on line documentation on backup and restore.
 	  *
 	  * @exception StandardException Thrown on error
 	  */
@@ -699,7 +699,7 @@
 
 	/**
 	  * Backup the database to backupDir.  
 	  * <P>Please see cloudscape on line documentation on backup and restore.
 	  *
 	  * @param backupDir the name of the directory where the backup should be
       *                  stored.
@@ -761,14 +761,14 @@
 		The raw store does not guarentee that a checkpoint will indeed have
 		happened by the time this routine returns.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void checkpoint() throws StandardException;
 
 
 	/**
 		Idle the raw store as much as possible. 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 	*/
 	public void idle() throws StandardException;
@@ -777,7 +777,7 @@
 	    Get a flushed scan.
 		@param start The instant for the beginning of the scan.
 		@param groupsIWant log record groups the caller wants to scan.
-		@exception StandardException StandardCloudscape error policy
+		@exception StandardException StandardDerby error policy
 		*/
 	ScanHandle openFlushedScan(DatabaseInstant start, int groupsIWant) 
 		 throws StandardException;
@@ -809,21 +809,21 @@
 	 * Return the module providing XAresource interface to the transaction 
      * table. 
      *
 	 * @exception StandardException Standard cloudscape exception policy.
 	 */
 	public /* XAResourceManager */ Object getXAResourceManager()
         throws StandardException;
 
 	/*
 	 * the database creation phase is finished
 	 * @exception StandardException Standard cloudscape exception policy.
 	 */
 	public void createFinished() throws StandardException;
 
 	/**
 	 * Get JBMS properties relavent to raw store
 	 *
 	 * @exception StandardException Standard cloudscape exception policy.
 	 */
 	public void getRawStoreProperties(PersistentSet tc) 
 		 throws StandardException; 
@@ -835,14 +835,14 @@
 	/**
 	 * Freeze the database from altering any persistent storage.
 	 *
 	 * @exception StandardException Standard cloudscape exception policy.
 	 */
 	public void freezePersistentStore() throws StandardException;
 
 	/**
 	 * Unfreeze the database, persistent storage can now be altered.
 	 *
 	 * @exception StandardException Standard cloudscape exception policy.
 	 */
 	public void unfreezePersistentStore() throws StandardException;
 
@@ -850,7 +850,7 @@
 		Encrypt cleartext into ciphertext.
 
 		@see org.apache.derby.iapi.services.crypto.CipherProvider#encrypt
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public int encrypt(byte[] cleartext, int offset, int length, 
 					   byte[] ciphertext, int outputOffset,
@@ -861,7 +861,7 @@
 		Decrypt cleartext from ciphertext.
 
 		@see org.apache.derby.iapi.services.crypto.CipherProvider#decrypt
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public int decrypt(byte[] ciphertext, int offset, int length, 
 					   byte[] cleartext, int outputOffset) 
@@ -882,7 +882,7 @@
 		Change the boot password.  Return the encrypted form of the secret key.
 		The new value must be a String of the form: oldBootPassword, newBootPassword
 
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public Serializable changeBootPassword(Properties properties, Serializable changePassword)
 		 throws StandardException ;
@@ -683,7 +683,7 @@
 	/**
 	  * Freeze the database temporarily so a backup can be taken.
-	  * <P>Please see cloudscape on line documentation on backup and restore.
+	  * <P>Please see Derby on line documentation on backup and restore.
 	  *
 	  * @exception StandardException Thrown on error
@@ -691,7 +691,7 @@
 	/**
 	  * Unfreeze the database after a backup has been taken.
-	  * <P>Please see cloudscape on line documentation on backup and restore.
+	  * <P>Please see Derby on line documentation on backup and restore.
 	  *
 	  * @exception StandardException Thrown on error
@@ -699,7 +699,7 @@
 	/**
 	  * Backup the database to backupDir.  
-	  * <P>Please see cloudscape on line documentation on backup and restore.
+	  * <P>Please see Derby on line documentation on backup and restore.
 	  *
 	  * @param backupDir the name of the directory where the backup should be
@@ -809,21 +809,21 @@
      * table. 
      *
-	 * @exception StandardException Standard cloudscape exception policy.
+	 * @exception StandardException Standard Derby exception policy.
 	 */
 	public /* XAResourceManager */ Object getXAResourceManager()
@@ -809,21 +809,21 @@
 	/*
 	 * the database creation phase is finished
-	 * @exception StandardException Standard cloudscape exception policy.
+	 * @exception StandardException Standard Derby exception policy.
 	 */
 	public void createFinished() throws StandardException;
@@ -809,21 +809,21 @@
 	 * Get JBMS properties relavent to raw store
 	 *
-	 * @exception StandardException Standard cloudscape exception policy.
+	 * @exception StandardException Standard Derby exception policy.
 	 */
 	public void getRawStoreProperties(PersistentSet tc) 
@@ -835,14 +835,14 @@
 	 * Freeze the database from altering any persistent storage.
 	 *
-	 * @exception StandardException Standard cloudscape exception policy.
+	 * @exception StandardException Standard Derby exception policy.
 	 */
 	public void freezePersistentStore() throws StandardException;
@@ -835,14 +835,14 @@
 	 * Unfreeze the database, persistent storage can now be altered.
 	 *
-	 * @exception StandardException Standard cloudscape exception policy.
+	 * @exception StandardException Standard Derby exception policy.
 	 */
 	public void unfreezePersistentStore() throws StandardException;

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/StreamContainerHandle.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/StreamContainerHandle.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/data/DataFactory.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/data/DataFactory.java Thu Mar  8 14:15:34 2007
@@ -80,7 +80,7 @@
 		then will return a null handle if the container is dropped.
 
 		@return the handle to the opened container
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 	 */
 	public ContainerHandle openContainer(RawTransaction t,
@@ -94,7 +94,7 @@
 		Only internal raw store code should call this, e.g. recovery.
 
 		@see #openContainer
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public RawContainerHandle openDroppedContainer(RawTransaction t,
 												   ContainerKey containerId,
@@ -115,7 +115,7 @@
 
 		@return the containerId of the newly created container
 
-		@exception StandardException Standard Cloudscape Error policy
+		@exception StandardException Standard Derby Error policy
 
 	 */
 	public long addContainer(
@@ -138,7 +138,7 @@
 
 		@return the containerId of the newly created stream container
 
-		@exception StandardException Standard Cloudscape Error policy
+		@exception StandardException Standard Derby Error policy
 
 	 */
 	public long addAndLoadStreamContainer(RawTransaction t, long segmentId,
@@ -150,7 +150,7 @@
 
 		@return a valid StreamContainerHandle or null if the container does not exist.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 
 	*/
 	public StreamContainerHandle openStreamContainer(
@@ -163,7 +163,7 @@
 	/**
 		Drop and remove a stream container.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public void dropStreamContainer(RawTransaction t, long segmentId, long containerId)
 		throws StandardException;
@@ -174,7 +174,7 @@
         Used if container is found to not exist during redo recovery of
         log records creating the container.
 
-		@exception StandardException Standard Cloudscape Error policy
+		@exception StandardException Standard Derby Error policy
 	 */
 	public void reCreateContainerForRedoRecovery(RawTransaction t,
 			long segmentId, long containerId, ByteArray containerInfo)
@@ -209,7 +209,7 @@
 		Return a record handle that is initialized to the given page number and
         record id.
 
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 
 		@param segmentId    segment where the RecordHandle belongs.
 		@param containerId  container where the RecordHandle belongs.
@@ -224,7 +224,7 @@
 	/**
 		Database creation finished
 
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 	*/
 	public void createFinished() throws StandardException;
 
@@ -251,7 +251,7 @@
 
 	/**
 		Reclaim space used by this factory.  Called by post commit daemon.
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public int reclaimSpace(Serviceable work, ContextManager contextMgr)
 		 throws StandardException;
@@ -259,7 +259,7 @@
 	/**
 		Called after recovery is performed.
 
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	*/
 	public void postRecovery() throws StandardException;
 
@@ -267,7 +267,7 @@
 		Encrypt cleartext into ciphertext.
 
 		@see org.apache.derby.iapi.services.crypto.CipherProvider#encrypt
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public int encrypt(byte[] cleartext, int offset, int length,
 					   byte[] ciphertext, int outputOffset, 
@@ -278,7 +278,7 @@
 		Decrypt cleartext from ciphertext.
 
 		@see org.apache.derby.iapi.services.crypto.CipherProvider#decrypt
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public int decrypt(byte[] ciphertext, int offset, int length,
 					   byte[] cleartext, int outputOffset)
@@ -315,7 +315,7 @@
 
 	/**
 	 * Backup restore - stop writing dirty pages or container to disk
 	 * @exception StandardException Standard Cloudscape error policy
 	 */
 	public void freezePersistentStore() throws StandardException;
 
@@ -327,7 +327,7 @@
 	/**
 	 * Backup restore - don't allow the persistent store to be frozen - or if
 	 * it is already frozen, block.   A write is about to commence.
 	 * @exception StandardException Standard Cloudscape error policy
 	 */
 	public void writeInProgress() throws StandardException;
 
@@ -363,7 +363,7 @@
 	 * during recovery. Crash recovery  uses these files to identify the dropped
 	 * containers.   Stub files(d*.dat) gets creates  when a
 	 * table/index(containers) dropped.
 	 * @exception StandardException Standard Cloudscape error policy
 	 **/
     public void removeDroppedContainerFileStubs(LogInstant redoLWM) throws StandardException;
 
@@ -315,7 +315,7 @@
 	/**
 	 * Backup restore - stop writing dirty pages or container to disk
-	 * @exception StandardException Standard Cloudscape error policy
+	 * @exception StandardException Standard Derby error policy
 	 */
 	public void freezePersistentStore() throws StandardException;
@@ -327,7 +327,7 @@
 	 * Backup restore - don't allow the persistent store to be frozen - or if
 	 * it is already frozen, block.   A write is about to commence.
-	 * @exception StandardException Standard Cloudscape error policy
+	 * @exception StandardException Standard Derby error policy
 	 */
 	public void writeInProgress() throws StandardException;
@@ -363,7 +363,7 @@
 	 * containers.   Stub files(d*.dat) gets creates  when a
 	 * table/index(containers) dropped.
-	 * @exception StandardException Standard Cloudscape error policy
+	 * @exception StandardException Standard Derby error policy
 	 **/
     public void removeDroppedContainerFileStubs(LogInstant redoLWM) throws StandardException;

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/data/RawContainerHandle.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/data/RawContainerHandle.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/data/RawContainerHandle.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/data/RawContainerHandle.java Thu Mar  8 14:15:34 2007
@@ -54,27 +54,27 @@
 
 	/** 
 		Return the status of the container - one of NORMAL, DROPPED, COMMITTED_DROP.
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public int getContainerStatus() throws StandardException;
 
 	/**
 		Remove the container.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public void removeContainer(LogInstant instant) throws StandardException;
 
 	/**
 		If drop is true, drop the container.  if drop is false, un-drop the
 		container
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public void dropContainer(LogInstant instant, boolean drop) throws StandardException;
 
 	/**
 		Get the logged container version
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public long getContainerVersion() throws StandardException;
 
@@ -82,7 +82,7 @@
 		Return a Page that represents any page - alloc page, valid page, free page, 
 		dealloced page etc.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Page getAnyPage(long pageNumber) throws StandardException;
 
@@ -95,7 +95,7 @@
         Used during redo recovery while trying to apply log records which
         are creating the page.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public Page reCreatePageForRedoRecovery(
     int     pageFormat, 
@@ -107,7 +107,7 @@
 		Log all information necessary to recreate the container during a load
 		tran.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public ByteArray logCreateContainerInfo() throws StandardException;
 
@@ -117,7 +117,7 @@
 	   checkpoint is taken after any log record is sent to the log stream but
 	   before the container is actually dirtied.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	public void preDirty(boolean preDirtyOn) throws StandardException;
 
@@ -126,7 +126,7 @@
      * Create encrypted version of the container with the 
      * user specified encryption properties.  
      * @param newFilePath file to store the new encrypted version of the container
 	 * @exception StandardException	Standard Cloudscape error policy
      */
 	public void encryptContainer(String newFilePath) throws StandardException;
 
@@ -126,7 +126,7 @@
      * user specified encryption properties.  
      * @param newFilePath file to store the new encrypted version of the container
-	 * @exception StandardException	Standard Cloudscape error policy
+	 * @exception StandardException	Standard Derby error policy
      */
 	public void encryptContainer(String newFilePath) throws StandardException;

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/log/LogFactory.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/log/LogFactory.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/xact/TransactionFactory.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/iapi/store/raw/xact/TransactionFactory.java Thu Mar  8 14:15:34 2007
@@ -65,7 +65,7 @@
 	 * Return the module providing XAresource interface to the transaction
      * table.
      *
 	 * @exception StandardException Standard cloudscape exception policy.
 	 */
 	public /* XAResourceManager */ Object getXAResourceManager()
         throws StandardException;
@@ -82,7 +82,7 @@
 
 		@see RawStoreFactory#startTransaction
 
-		@exception StandardException Standard Cloudscape error policy.
+		@exception StandardException Standard Derby error policy.
 	*/
 	public RawTransaction startTransaction(
     RawStoreFactory rsf,
@@ -103,7 +103,7 @@
 
 		@see RawStoreFactory#startNestedReadOnlyUserTransaction
 
-		@exception StandardException Standard Cloudscape error policy.
+		@exception StandardException Standard Derby error policy.
 	*/
 	public RawTransaction startNestedReadOnlyUserTransaction(
     RawStoreFactory rsf,
@@ -124,7 +124,7 @@
 
 		@see RawStoreFactory#startNestedUpdateUserTransaction
 
-		@exception StandardException Standard Cloudscape error policy.
+		@exception StandardException Standard Derby error policy.
 	*/
 	public RawTransaction startNestedUpdateUserTransaction(
     RawStoreFactory rsf,
@@ -148,7 +148,7 @@
 
 		@see RawStoreFactory#startGlobalTransaction
 
-		@exception StandardException Standard Cloudscape error policy.
+		@exception StandardException Standard Derby error policy.
 	*/
 	public RawTransaction startGlobalTransaction(
     RawStoreFactory rsf,
@@ -167,7 +167,7 @@
 		@see RawStoreFactory#findUserTransaction
 		@see RawStoreFactory#startTransaction
 
-		@exception StandardException Standard Cloudscape error policy.
+		@exception StandardException Standard Derby error policy.
 	*/
 	public RawTransaction findUserTransaction(
         RawStoreFactory rsf,
@@ -181,7 +181,7 @@
 
 		@see RawStoreFactory#startTransaction(ContextManager, String)
 
-		@exception StandardException Standard Cloudscape error policy.
+		@exception StandardException Standard Derby error policy.
 	*/
 	public RawTransaction startNestedTopTransaction(RawStoreFactory rsf, ContextManager contextMgr) throws StandardException;
 
@@ -193,7 +193,7 @@
 
 		@see RawStoreFactory#startTransaction
 
-		@exception StandardException Standard Cloudscape error policy.
+		@exception StandardException Standard Derby error policy.
 	*/
 	public RawTransaction startInternalTransaction(RawStoreFactory rsf, ContextManager contextMgr) throws StandardException;
 
@@ -208,7 +208,7 @@
 
 	/**
 		Reset any resettable transaction Id 
-		@exception StandardException Standard Cloudscape error policy.
+		@exception StandardException Standard Derby error policy.
 	*/
 	public void resetTranId() throws StandardException;
 
@@ -228,7 +228,7 @@
 
 		Used only in recovery.
 
-		@exception StandardException Cloudscape Standard Error policy
+		@exception StandardException Derby Standard Error policy
 	*/
 	public void handlePreparedXacts(
     RawStoreFactory rsf)
@@ -240,7 +240,7 @@
 		passed in transaction.  Used only in recovery.
 
 		@param recoveryTransaction the transaction used to rollback
-		@exception StandardException Cloudscape Standard Error policy
+		@exception StandardException Derby Standard Error policy
 	*/
 	public void rollbackAllTransactions(RawTransaction recoveryTransaction, 
 										RawStoreFactory rsf)
@@ -284,7 +284,7 @@
 	/**
 		Database creation finished
 
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 	*/
 	public void createFinished() throws StandardException;
 
@@ -298,7 +298,7 @@
 		Use this transaction table, which is gotten from a checkpoint
 		operation.  Use ONLY during recovery.
 
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 	 */
 	public void useTransactionTable(Formatable transactionTable) 
 		 throws StandardException; 
@@ -65,7 +65,7 @@
      * table.
      *
-	 * @exception StandardException Standard cloudscape exception policy.
+	 * @exception StandardException Standard Derby exception policy.
 	 */
 	public /* XAResourceManager */ Object getXAResourceManager()

Modified: db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/DataTypeDescriptor.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/iapi/types/DataTypeDescriptor.java?view=diff&rev=516194&r1=516193&r2=516194
==============================================================================